@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: create_pages.py 10591 2017-12-03 05:37:16Z Lavender $
+# $Id: create_pages.py 10626 2017-12-10 09:05:41Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,11 +12,12 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-12-03 13:37:16 +0800 (週日, 03 十二月 2017) $
-# $Revision: 10591 $
+# $Date: 2017-12-10 17:05:41 +0800 (週日, 10 十二月 2017) $
+# $Revision: 10626 $
 
 import os
 import json
+import traceback
 
 from django.core.management.base import BaseCommand
 from django.conf import settings
@@ -115,6 +116,8 @@ class Command(BaseCommand):
             logger.info('All OK!!')
         except Exception as e:
             logger.error("create_pages error:%s" % e)
+            with open('./AllError.log', 'w+') as log:
+                log.write(traceback.format_exc())
             raise
 
     def getPageData(self, path):
