@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: pluginize.py 10591 2017-12-03 05:37:16Z Lavender $
+# $Id: pluginize.py 10626 2017-12-10 09:05:41Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,14 +12,15 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-12-03 13:37:16 +0800 (週日, 03 十二月 2017) $
-# $Revision: 10591 $
+# $Date: 2017-12-10 17:05:41 +0800 (週日, 10 十二月 2017) $
+# $Revision: 10626 $
 
 import os
 import json
 import logging
 import shutil
 import hashlib
+import traceback
 
 from django.core.management.base import BaseCommand, CommandError
 from django.core.management import call_command
@@ -28,6 +29,7 @@ from django.db import transaction
 from django.template.loader import get_template
 from django.template import Context
 from django.conf import settings
+from django.template import Template
 
 from djangocms_text_ckeditor.cms_plugins import TextPlugin
 from cms.templatetags.cms_tags import *
@@ -69,7 +71,6 @@ class Placeholder2(Placeholder):
     lang = 'zh-hant'
 
     def render_tag(self, context, name, extra_bits, nodelist=None):
-
         super(Placeholder2, self).render_tag(context, name,
                                                        extra_bits, nodelist)
         content = nodelist.render(context)
@@ -194,11 +195,10 @@ class Placeholder2(Placeholder):
                             plugin_type='FilerImagePlugin',)
                     
                 else:
-                
-                    Text.objects.create(placeholder=placeholder,
-                                        language=Placeholder2.lang,
-                                        body=content, plugin_type='TextPlugin')
-
+                    textPlugin = Text.objects.create(
+                        placeholder=placeholder,
+                        language=Placeholder2.lang,
+                        body=content, plugin_type='TextPlugin')
 
 class Command(BaseCommand):
     
@@ -323,6 +323,8 @@ class Command(BaseCommand):
             logger.info('DONE!')
         except Exception as e:
             logger.error("pluginize error:%s" % e)
+            with open('./AllError.log', 'w+') as log:
+                log.write(traceback.format_exc())
             raise
         
 
