@@ -107,7 +107,6 @@ $j(document).ready(function() {
             };
             
             if(p){
-                console.log(p);
                 var jp = $j(p);
                 
                 var comment = null;
@@ -122,8 +121,6 @@ $j(document).ready(function() {
                     };
                 };
                 
-                console.log(tagList);
-                
                 for(var i = 0;i < tagList.length; i++) {
                     p.appendChild(tagList[i]);
                 };   
